-- 创建菜单分类表
CREATE TABLE
    menu_cate (
        id INTEGER PRIMARY KEY AUTOINCREMENT, -- 主键
        name TEXT DEFAULT '', -- 分类名称
        logo TEXT DEFAULT '', -- 分类Logo
        local_logo TEXT DEFAULT '', -- 本地Logo路径
        description TEXT, -- 分类描述
        create_time DATETIME DEFAULT NULL, -- 创建时间
        update_time DATETIME DEFAULT NULL, -- 更新时间
        sort INTEGER DEFAULT 0, -- 排序
        status TEXT DEFAULT 'A' -- 状态 (A-Active, D-Deleted)
    );

-- 创建商品表
CREATE TABLE
    menu_commodity (
        id INTEGER PRIMARY KEY AUTOINCREMENT, -- 主键
        type TEXT DEFAULT 'product', -- 商品类型
        merchant_id INTEGER DEFAULT 0, -- 商户ID
        store_id INTEGER DEFAULT 0, -- 店铺ID
        name TEXT DEFAULT '', -- 商品名称
        cate_id INTEGER DEFAULT 0, -- 分类ID
        goods_no TEXT DEFAULT '', -- 商品编号
        is_single_spec TEXT DEFAULT 'Y', -- 是否单规格 (Y-Yes, N-No)
        logo TEXT DEFAULT '', -- 商品Logo
        images TEXT DEFAULT '', -- 商品图片
        price REAL DEFAULT 0.00, -- 价格
        line_price REAL DEFAULT 0.00, -- 划线价
        stock INTEGER DEFAULT 0, -- 库存
        weight REAL DEFAULT 0.00, -- 重量
        coupon_ids TEXT DEFAULT '', -- 优惠券ID
        service_time INTEGER DEFAULT 0, -- 服务时间
        init_sale INTEGER DEFAULT 0, -- 初始销量
        sale_point TEXT DEFAULT '', -- 卖点
        can_use_point TEXT DEFAULT 'N', -- 是否可用积分 (Y-Yes, N-No)
        is_member_discount TEXT DEFAULT 'Y', -- 是否会员折扣 (Y-Yes, N-No)
        sort INTEGER DEFAULT 0, -- 排序
        description TEXT, -- 商品描述
        create_time DATETIME DEFAULT NULL, -- 创建时间
        update_time DATETIME DEFAULT NULL, -- 更新时间
        operator TEXT DEFAULT NULL, -- 操作员
        status TEXT DEFAULT 'A' -- 状态 (A-Active, D-Deleted)
    );

-- 创建SKU表
CREATE TABLE
    menu_sku (
        id INTEGER PRIMARY KEY AUTOINCREMENT, -- 主键
        sku_no TEXT DEFAULT '', -- SKU编号
        logo TEXT DEFAULT '', -- SKU Logo
        goods_id INTEGER NOT NULL DEFAULT 0, -- 商品ID
        stock INTEGER NOT NULL DEFAULT 0, -- 库存
        price REAL NOT NULL DEFAULT 0.00, -- 价格
        line_price REAL NOT NULL DEFAULT 0.00, -- 划线价
        weight REAL DEFAULT 0.00, -- 重量
        status TEXT NOT NULL DEFAULT 'A' -- 状态 (A-Active, D-Deleted)
    );

-- 创建规格表
CREATE TABLE
    menu_spec (
        id INTEGER PRIMARY KEY AUTOINCREMENT, -- 主键
        goods_id INTEGER NOT NULL DEFAULT 0, -- 商品ID
        name TEXT NOT NULL DEFAULT '', -- 规格名称
        value TEXT NOT NULL DEFAULT '', -- 规格值
        status TEXT DEFAULT 'A' -- 状态 (A-Active, D-Deleted)
    );

-- 创建SKU和规格的中间表
CREATE TABLE
    menu_sku_spec (
        sku_id INTEGER NOT NULL, -- SKU ID
        spec_id INTEGER NOT NULL, -- 规格ID
        PRIMARY KEY (sku_id, spec_id),
        FOREIGN KEY (sku_id) REFERENCES menu_sku (id),
        FOREIGN KEY (spec_id) REFERENCES menu_spec (id)
    );