import { Generated, Insertable, Selectable, Updateable } from 'kysely'

// 商品表
export interface MenuCommodityTable {
  id: Generated<number> // 主键
  type: string // 商品类型
  merchantId: number // 商户ID
  storeId: number // 店铺ID
  name: string // 商品名称
  cateId: number // 分类ID
  goodsNo: string // 商品编号
  isSingleSpec: 'Y' | 'N' // 是否单规格 (Y-Yes, N-No)
  logo: string // 商品Logo
  images: string // 商品图片
  price: number // 价格
  linePrice: number // 划线价
  stock: number // 库存
  weight: number // 重量
  couponIds: string // 优惠券ID
  serviceTime: number // 服务时间
  initSale: number // 初始销量
  salePoint: string // 卖点
  canUsePoint: 'Y' | 'N' // 是否可用积分 (Y-Yes, N-No)
  isMemberDiscount: 'Y' | 'N' // 是否会员折扣 (Y-Yes, N-No)
  sort: number // 排序
  description?: string // 商品描述
  createTime?: string // 创建时间
  updateTime?: string // 更新时间
  operator?: string // 操作员
  status: 'A' | 'D' // 状态 (A-Active, D-Deleted)
}

export type MenuCommodity = Selectable<MenuCommodityTable>
export type NewMenuCommodity = Insertable<MenuCommodityTable>
export type MenuCommodityUpdate = Updateable<MenuCommodityTable>
